import { TransitionGroup, defineComponent, reactive } from 'vue';
import styles from './index.module.less';
import MSearch from '@/components/m-search';
import icon_play from '@/common/images/icon_play.svg';
import { NoticeBar, showToast } from 'vant';
import icon_back from './image/icon_back.svg';
import icon_down from '@/common/images/icon_down.svg';
import icon_jianpu from '@/common/images/icon_jianpu.svg';
import icon_jianpuActive from '@/common/images/icon_jianpuActive.svg';
import icon_start from '@/common/images/icon_start.svg';
import icon_1 from './image/1.svg';
import icon_2 from './image/2.svg';
import icon_3 from './image/3.svg';
import png_1 from './image/1.png';
import png_2 from './image/2.png';
import png_3 from './image/3.png';
import png_4 from './image/4.png';
import { postMessage, promisefiyPostMessage } from '@/helpers/native-message';
import { rows } from './data.json';
export default defineComponent({
  name: 'co-ai',
  setup() {
    const icons = [icon_1, icon_2, icon_3];
    const types = [
      { src: 'https://daya.ks3-cn-beijing.ksyuncs.com/16880147803671.png' },
      { src: 'https://daya.ks3-cn-beijing.ksyuncs.com/16880147833062.png' },
      { src: 'https://daya.ks3-cn-beijing.ksyuncs.com/16880147854153.png' },
      { src: 'https://daya.ks3-cn-beijing.ksyuncs.com/16880147881254.png' },
      { src: 'https://daya.ks3-cn-beijing.ksyuncs.com/16880147939485.png' }
    ];
    const titles = rows;
    const data = reactive({
      /** 教材Index */
      typeIndex: 0,
      /** 音乐Index */
      musicIndex: 0,
      /** 显示简谱 */
      isShowJianpu: false
    });
    // 返回
    const goback = () => {
      postMessage({ api: 'goBack' });
    };
    /** 去云教练 */
    const handleGoto = () => {
      let src = `https://dev.kt.colexiu.com/instrument?id=43539&Authorization=bearer 529d1359-20c6-4ea2-b2ba-2694cdeda8a4`;
      postMessage({
        api: 'openAccompanyWebView',
        content: {
          url: src,
          orientation: 0,
          isHideTitle: true,
          statusBarTextColor: false,
          isOpenLight: true
        }
      });
    };
    /** 保存图片 */
    const handleSave = async () => {
      var canvas = document.createElement('canvas'); //创建canvas DOM元素
      var ctx = canvas.getContext('2d');
      const src = data.isShowJianpu
        ? data.musicIndex % 2 === 0
          ? 'https://cloud-coach.ks3-cn-beijing.ksyuncs.com/music-sheet-first/1687673062603-1.png'
          : 'https://cloud-coach.ks3-cn-beijing.ksyuncs.com/music-sheet-first/1675232855321-1.png'
        : data.musicIndex % 2 === 0
        ? 'https://cloud-coach.ks3-cn-beijing.ksyuncs.com/music-sheet/1687673062488-1.png'
        : 'https://cloud-coach.ks3-cn-beijing.ksyuncs.com/music-sheet/1675232854483-2.png';
      const bimg = new Image();
      bimg.crossOrigin = 'anonymous';
      bimg.src = src + '?v=' + Date.now();
      bimg.onload = async () => {
        canvas.height = bimg.height;
        canvas.width = bimg.width;
        ctx?.drawImage(bimg, 0, 0, bimg.width, bimg.height);
        var dataURL = canvas.toDataURL('image/png', 1); //可选取多种模式
        // console.log("🚀 ~ dataURL:", dataURL);
        (canvas as any) = null;
        setTimeout(() => {
          showToast('保存成功');
        }, 500);
        const res = await promisefiyPostMessage({
          api: 'savePicture',
          content: {
            base64: dataURL
          }
        });
        console.log('🚀 ~ res:', res);
      };
    };
    return () => (
      <div class={styles.container}>
        <div class={styles.back} onClick={goback}>
          <img src={icon_back} />
        </div>
        <div class={styles.content}>
          <div class={[styles.leftContent]}>
            <div class={styles.leftBg2}></div>
            <div class={styles.leftBg}></div>
            <div class={styles.types}>
              {types.map((item, index) => {
                return (
                  <div
                    class={[
                      styles.type,
                      data.typeIndex === index && styles.typeActive
                    ]}
                    onClick={() => (data.typeIndex = index)}>
                    <div class={styles.typeImg}>
                      <img class={styles.typeIcon} src={item.src} />
                    </div>
                  </div>
                );
              })}
            </div>
            <div class={styles.center}>
              <MSearch
                shape="round"
                background="transparent"
                placeholder="请输入曲目名称"
              />
              <div class={styles.musicContent}>
                {titles.map((item, index) => {
                  return (
                    <div
                      class={[
                        styles.musicItem,
                        data.musicIndex === index
                          ? styles.musicActive
                          : styles.disableNotic
                      ]}
                      onClick={() => (data.musicIndex = index)}>
                      <img class={styles.musicAvtor} src={item.titleImg} />
                      <div class={styles.musicInfo}>
                        <div class={styles.musicName}>
                          <NoticeBar
                            text={item.musicSheetName}
                            color="#333"
                            class={styles.noticeBar}
                            background="none"
                          />
                        </div>
                        <div class={styles.musicDes}>
                          <div class={styles.musicFavitor}>{item.updateBy}</div>
                          <div class={[styles.musicAuthor, 'van-ellipsis']}>
                            {item.composer}
                          </div>
                        </div>
                      </div>
                      {/* <img class={[styles.musicIcon]} src={icon_play} /> */}
                    </div>
                  );
                })}
              </div>
            </div>
          </div>
          <div class={[styles.opacityBg, styles.right]}>
            <div class={styles['right-musicName']}>
              {titles[data.musicIndex].musicSheetName}
            </div>
            {data.isShowJianpu ? (
              <>
                <TransitionGroup name="van-fade">
                  {titles[data.musicIndex]?.firstTone
                    ?.split(',')
                    .map((item, index) => {
                      return <img class={styles.staff} src={item} key={item} />;
                    })}
                </TransitionGroup>
              </>
            ) : (
              <>
                <TransitionGroup name="van-fade">
                  {titles[data.musicIndex]?.musicImg
                    ?.split(',')
                    .map((item, index) => {
                      return <img class={styles.staff} src={item} key={item} />;
                    })}
                </TransitionGroup>
              </>
            )}

            <div class={styles.rightBtns}>
              <img
                src={data.isShowJianpu ? icon_jianpuActive : icon_jianpu}
                onClick={() => (data.isShowJianpu = !data.isShowJianpu)}
              />
              <img src={icon_down} onClick={handleSave} />
              <img src={icon_start} onClick={() => handleGoto()} />
            </div>
          </div>
        </div>
      </div>
    );
  }
});
